/*
  Scanner.cpp
   (c)2022 Forward Computing and Control Pty. Ltd.
   NSW Australia, www.forward.com.au
   This code is not warranted to be fit for any purpose. You may only use it at your own risk.
   This code may be freely used for both private and commercial use
   Provide this copyright is maintained.
*/

#include <BLEDevice.h>
#include <SafeString.h>
#include <millisDelay.h>

static const int scanTime = 5; // 5sec

static Print* debugPtr = NULL;
void setScannerDebugOut(Print* outPtr) {
  debugPtr = outPtr;
}

static bool scannerRunning = false;
static bool startCalled = false;

static void scanComplete(BLEScanResults results);

void startScanner(BLEAdvertisedDeviceCallbacks* pAdvertisedDeviceCallbacks) {
  if (scannerRunning) {
    return;
  }
  BLEDevice::init(""); // can call more than once OK
  startCalled = true;
  
  // Retrieve a Scanner and set the callback we want to use to be informed when we
  // have detected a new device.  Specify that we want active scanning and start the
  // scan to run for 5 seconds.
  BLEScan* pBLEScan = BLEDevice::getScan();
  if (pAdvertisedDeviceCallbacks) {
    pBLEScan->setAdvertisedDeviceCallbacks(pAdvertisedDeviceCallbacks, false);
  }
  pBLEScan->setInterval(1349);
  pBLEScan->setWindow(449);
  if (debugPtr) {
    debugPtr->println("Starting scan");
  }
  if (pBLEScan->start(scanTime, scanComplete, false) ) {
    scannerRunning = true;
  }
}

void restartScanner() {
  if (!startCalled) {
    return;
  }
  if (scannerRunning) {
    return;
  }
  if (debugPtr) {
    debugPtr->println("Restarting scan");
  }
  if (BLEDevice::getScan()->start(scanTime, scanComplete, false) ) {
    scannerRunning = true;
  }
}

void stopScanner() {
  if (!scannerRunning) {
    return;
  }
  scannerRunning = false;
  BLEScan* pBLEScan = BLEDevice::getScan();
  pBLEScan->stop();

}

void scanComplete(BLEScanResults results) {
  (void)results; // not used use MyAdvertisedDeviceCallbacks instead
  scannerRunning = false;
}
